package com.younike.system.mapper;

import com.younike.system.domain.CateDimension;
import com.younike.system.domain.vo.CateDimensionVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 分类维度Mapper接口
 * 
 * @author elev
 * @date 2022-01-04
 */
public interface CateDimensionMapper {

    /**
     * 批量添加
     * @param cateDimensionList
     * @return
     */
    int insertBatch(@Param("cateDimensionList") List<CateDimension> cateDimensionList);
    /**
     * 查询分类维度
     * 
     * @param id 分类维度主键
     * @return 分类维度
     */
    CateDimension selectCateDimensionById(Long id);

    /**
     * 查询分类维度列表
     * 
     * @param cateDimension 分类维度
     * @return 分类维度集合
     */
    List<CateDimension> selectCateDimensionList(CateDimension cateDimension);

    /**
     * 新增分类维度
     * 
     * @param cateDimension 分类维度
     * @return 结果
     */
    int insertCateDimension(CateDimension cateDimension);

    /**
     * 修改分类维度
     * 
     * @param cateDimension 分类维度
     * @return 结果
     */
    int updateCateDimension(CateDimension cateDimension);

    /**
     * 删除分类维度
     * 
     * @param id 分类维度主键
     * @return 结果
     */
    int deleteCateDimensionById(Long id);

    /**
     * 批量删除分类维度
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCateDimensionByIds(Long[] ids);

    /**
     * 通过分类id查询分类维度列表
     *
     * @param categoryId
     * @return
     */
    List<CateDimensionVo> listByCategoryId(Long categoryId);
}
